=======
Credits
=======

Development Lead
----------------

* Jamil Atta Junior <jamil.atta@scielo.org>
* Juan Ernesto Funez <juan.funez@scielo.org>

Contributors
------------

None yet. Why not be the first?
